# lin-mail-sender #

Esse pacote foi feito para usar a api-mail-sender
### ENVS requiridas ###

* HOST_MAIL
* PORT_MAIL
* USER_MAIL
* PASSWORD_MAIL

### Utilizar Metodo ###

- send
  - Parametros
    - **sender** // Email do remetente
    - **name_sender** // Nome remetente
    - **address** // Email do destinatario
    - **name_address** // Nome do destinatario
    - **subject** // Assunto
    - **text** // Texto do email
    - **confirm** // Confirmar email, por padr�o vem falso
